@@ -9,12 +9,14 @@ from openstef_dbc.config.enums import RuntimeEnv, Namespace
 
 
 def determine_runtime_environment():
-    """Determine the runtime environment
+    """Determine the runtime environment based on environment variables
+
+    Note that 'jenkins' is considered local
 
     Returns:
         RunTimeEnv: Runtime environment (LOCAL or CONTAINER)
     """
-    if "KUBERNETES_SERVICE_HOST" in os.environ:
+    if "KUBERNETES_SERVICE_HOST" in os.environ and "JENKINS_VERSION" not in os.environ:
         return RuntimeEnv.CONTAINER
     return RuntimeEnv.LOCAL
 
